@@ -37,7 +37,9 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
     if(plot.time && !plot.seasons) {
         nRows <- 1
         nCols <- 1
-        par(mfrow = c(nRows, nCols))
+        
+        ##reset graphics parameters and save in object
+        oldpar <- par(mfrow = c(nRows, nCols))
     }
 
     
@@ -47,55 +49,56 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
             n.seasons.adj <- 12
             warning("\nOnly first 12 seasons are plotted\n")
         }
-    }
+    
+        if(plot.seasons && n.seasons.adj <= 12) {
 
-
-    if(plot.seasons && n.seasons.adj <= 12) {
-
-        ##if n.seasons < 12
-        ##if 12, 11, 10 <- 4 x 3
-        ##if 9, 8, 7 <- 3 x 3
-        ##if 6, 5 <- 3 x 2
-        ##if 4 <- 2 x 2
-        ##if 3 <- 3 x 1
-        ##if 2 <- 2 x 1
+            ##if n.seasons < 12
+            ##if 12, 11, 10 <- 4 x 3
+            ##if 9, 8, 7 <- 3 x 3
+            ##if 6, 5 <- 3 x 2
+            ##if 4 <- 2 x 2
+            ##if 3 <- 3 x 1
+            ##if 2 <- 2 x 1
         
-        if(n.seasons.adj >= 10) {
-            nRows <- 4
-            nCols <- 3
-        } else {
-            
-            if(n.seasons.adj >= 7) {
-                nRows <- 3
+            if(n.seasons.adj >= 10) {
+                nRows <- 4
                 nCols <- 3
             } else {
-                
-                if(n.seasons.adj >= 5) {
+            
+                if(n.seasons.adj >= 7) {
                     nRows <- 3
-                    nCols <- 2
+                    nCols <- 3
                 } else {
-                    if(n.seasons.adj == 4) {
-                        nRows <- 2
+                
+                    if(n.seasons.adj >= 5) {
+                        nRows <- 3
                         nCols <- 2
                     } else {
-                        if(n.seasons.adj == 3) {
-                            nRows <- 3
-                            nCols <- 1
-                        } else {
+                        if(n.seasons.adj == 4) {
                             nRows <- 2
-                            nCols <- 1
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 3) {
+                                nRows <- 3
+                                nCols <- 1
+                            } else {
+                                nRows <- 2
+                                nCols <- 1
+                            }
                         }
                     }
                 }
             }
+            ##reset graphics parameters and save in object
+            oldpar <- par(mfrow = c(nRows, nCols))
         }
-        par(mfrow = c(nRows, nCols))
     }
+    
 
 
 
     ##if both plots for seasons and combined are requested
-    if(plot.time) {
+    if(plot.time && plot.seasons) {
         
         if(plot.seasons && n.seasons >= 12) {
             n.seasons.adj <- 11
@@ -132,16 +135,16 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
             }
         }
         
-        par(mfrow = c(nRows, nCols))
+        ##reset graphics parameters and save in object
+        oldpar <- par(mfrow = c(nRows, nCols))
     }
-
         
-            
+        
     ##combine all seasons
     ##Censoring distance
     censoredDist.full <- surveyLength
     uniqueDist.full <- unique(as.vector(censoredDist.full))
-        
+    
     ##determine data that were censored
     uncensoredIndex.full <- yMat < censoredDist.full
     uncensoredData.full <- yMat[uncensoredIndex.full]
@@ -181,13 +184,13 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
              xlab = "Time to detection (min.)",
              main = main.title, cex.axis = cex.axis, cex.lab = cex.lab, cex.main = cex.main)
     }
-
+        
 
     ##quantiles for entire data
-    time.table.full <- quantile(uncensoredData.full)
+    time.table.full <- quantile(uncensoredData.full, na.rm = TRUE)
 
     ##store data for each season
-
+    
     ##columns for each season
     col.seasons <- seq(1, nvisits, by = n.visits.season)
 
@@ -195,7 +198,7 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
     yMat.seasons <- vector(mode = "list", length = n.seasons)
     names(yMat.seasons) <- seasonNames
     minusOne <- n.visits.season - 1
-
+        
     ##list to store quantiles excluding censored times
     time.table.seasons <- vector("list", n.seasons)
     names(time.table.seasons) <- seasonNames
@@ -232,17 +235,19 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
         uncensoredData <- yMat1[uncensoredIndex]
         uncensoredData.seasons[[i]] <- uncensoredData
         ncensored <- nsites - sum(uncensoredIndex)
-
+        
         ##summarize times per season
-        time.quantiles <- quantile(uncensoredData)
+        time.quantiles <- quantile(uncensoredData, na.rm = TRUE)
         time.table.seasons[[i]] <- time.quantiles
         censored.seasons[i] <- ncensored
-
-    }
         
+    }
 
+    ##check if any seasons were not sampled
+    y.seasonsNA <- sapply(yMat.seasons, FUN = function(i) all(is.na(i)))
+    
     if(plot.seasons) {
-
+        
         for(i in 1:n.seasons) {
             
             if(length(uniqueDist.seasons[[i]]) == 1) {
@@ -256,9 +261,11 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
                                     sep = "")
             }
             
-            
+                
             ##create histogram
-            hist(uncensoredData, xlim = c(0, uniqueDist.seasons[[i]]),
+            ##check for missing season
+            if(y.seasonsNA[i]) {next} #skip to next season if current season not sampled
+            hist(uncensoredData.seasons[[i]], xlim = c(0, uniqueDist.seasons[[i]]),
                  xlab = "Time to detection (min.)",
                  main = main.title, cex.axis = cex.axis, cex.lab = cex.lab, cex.main = cex.main)
         }
@@ -274,7 +281,7 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
         for(i in 1:n.seasons) {
             ySeason <- yMat.seasons[[i]]
             censored <- censoredDist.seasons[[i]]
-
+            
             uncensoredObs <- matrix(NA, ncol = n.visits.season,
                                     nrow = nsites)
             
@@ -288,7 +295,7 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
             ##check sites with observed detections and deal with NA's
             sum.rows <- rowSums(uncensoredObs, na.rm = TRUE)
             is.na(sum.rows) <- rowSums(is.na(uncensoredObs)) == ncol(ySeason)
-                
+            
             ##number of sites sampled
             out.freqs[i, 1] <- sum(!is.na(sum.rows))
             out.freqs[i, 2] <- sum(det.sum)
@@ -333,7 +340,7 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
             ##check sites with observed detections and deal with NA's
             sum.rows <- rowSums(uncensoredObs, na.rm = TRUE)
             is.na(sum.rows) <- rowSums(is.na(uncensoredObs)) == ncol(ySeason)
-            
+                
             ##number of sites sampled
             out.freqs[i, 1] <- sum(!is.na(sum.rows))
             out.freqs[i, 2] <- sum(det.sum)
@@ -352,16 +359,27 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
             some1 <- out.seasons[[j-1]]$some
             none2 <- out.seasons[[j]]$none
             some2 <- out.seasons[[j]]$some
-            ##colonizations
-            out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
-            ##extinctions
-            out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
-            ##no change
-            out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
-            ##sites both sampled in t and t-1
-            year1 <- c(none1, some1)
-            year2 <- c(none2, some2)
-            out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+
+            ##add check for seasons without sampling or previous season without sampling
+            if(y.seasonsNA[j] || y.seasonsNA[j-1]) {
+                if(y.seasonsNA[j]) {
+                    out.freqs[j, 2:6] <- NA
+                }
+                if(y.seasonsNA[j-1]) {
+                    out.freqs[j, 3:6] <- NA
+                }
+            } else {
+                ##colonizations
+                out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
+                ##extinctions
+                out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
+                ##no change
+                out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
+                ##sites both sampled in t and t-1
+                year1 <- c(none1, some1)
+                year2 <- c(none2, some2)
+                out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+            }
         }
         
         ##create a matrix with proportion of sites with colonizations
@@ -369,22 +387,39 @@ detTime.unmarkedFrameOccuTTD <- function(object, plot.time = TRUE, plot.seasons
         out.props <- matrix(NA, nrow = nrow(out.freqs), ncol = 4)
         colnames(out.props) <- c("naive.occ", "naive.colonization", "naive.extinction", "naive.static")
         rownames(out.props) <- rownames(out.freqs)
-        out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
-        out.props[, 2] <- out.freqs[, 3]/out.freqs[, 6]
-        out.props[, 3] <- out.freqs[, 4]/out.freqs[, 6]
-        out.props[, 4] <- out.freqs[, 5]/out.freqs[, 6]
+        
+        for(k in 1:n.seasons) {
+            ##proportion of sites with detections
+            out.props[k, 1] <- out.freqs[k, 2]/out.freqs[k, 1]
+            ##add check for seasons without sampling
+            if(y.seasonsNA[k]) {
+                out.props[k, 2:4] <- NA
+            } else {
+                ##proportion colonized
+                out.props[k, 2] <- out.freqs[k, 3]/out.freqs[k, 6]
+                ##proportion extinct
+                out.props[k, 3] <- out.freqs[k, 4]/out.freqs[k, 6]
+                ##proportion static
+                out.props[k, 4] <- out.freqs[k, 5]/out.freqs[k, 6]
+            }
+        }
     }
 
+    ##reset to original values
+    if(any(plot.time || plot.seasons)) {
+        on.exit(par(oldpar))
+    }
     
     out.det <- list("time.table.full" = time.table.full,
                     "time.table.seasons" = time.table.seasons,
                     "out.freqs" = out.freqs, "out.props" = out.props,
                     "n.seasons" = n.seasons,
-                    "n.visits.season" = n.visits.season)
+                    "n.visits.season" = n.visits.season,
+                    "missing.seasons" = y.seasonsNA)
     class(out.det) <- "detTime"
     return(out.det)
 }
-
+    
 
 
 ##for occuTTD
@@ -410,7 +445,8 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
     if(plot.time && !plot.seasons) {
         nRows <- 1
         nCols <- 1
-        par(mfrow = c(nRows, nCols))
+        ##reset graphics parameters and save in object
+        oldpar <- par(mfrow = c(nRows, nCols))
     }
 
     
@@ -420,55 +456,55 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
             n.seasons.adj <- 12
             warning("\nOnly first 12 seasons are plotted\n")
         }
-    }
+    
+        if(plot.seasons && n.seasons.adj <= 12) {
 
-
-    if(plot.seasons && n.seasons.adj <= 12) {
-
-        ##if n.seasons < 12
-        ##if 12, 11, 10 <- 4 x 3
-        ##if 9, 8, 7 <- 3 x 3
-        ##if 6, 5 <- 3 x 2
-        ##if 4 <- 2 x 2
-        ##if 3 <- 3 x 1
-        ##if 2 <- 2 x 1
-        
-        if(n.seasons.adj >= 10) {
-            nRows <- 4
-            nCols <- 3
-        } else {
+            ##if n.seasons < 12
+            ##if 12, 11, 10 <- 4 x 3
+            ##if 9, 8, 7 <- 3 x 3
+            ##if 6, 5 <- 3 x 2
+            ##if 4 <- 2 x 2
+            ##if 3 <- 3 x 1
+            ##if 2 <- 2 x 1
             
-            if(n.seasons.adj >= 7) {
-                nRows <- 3
+            if(n.seasons.adj >= 10) {
+                nRows <- 4
                 nCols <- 3
             } else {
-                
-                if(n.seasons.adj >= 5) {
+            
+                if(n.seasons.adj >= 7) {
                     nRows <- 3
-                    nCols <- 2
+                    nCols <- 3
                 } else {
-                    if(n.seasons.adj == 4) {
-                        nRows <- 2
+                    
+                    if(n.seasons.adj >= 5) {
+                        nRows <- 3
                         nCols <- 2
                     } else {
-                        if(n.seasons.adj == 3) {
-                            nRows <- 3
-                            nCols <- 1
-                        } else {
+                        if(n.seasons.adj == 4) {
                             nRows <- 2
-                            nCols <- 1
+                            nCols <- 2
+                        } else {
+                            if(n.seasons.adj == 3) {
+                                nRows <- 3
+                                nCols <- 1
+                            } else {
+                                nRows <- 2
+                                nCols <- 1
+                            }
                         }
                     }
                 }
             }
+            ##reset graphics parameters and save in object
+            oldpar <- par(mfrow = c(nRows, nCols))
         }
-        par(mfrow = c(nRows, nCols))
     }
 
 
 
     ##if both plots for seasons and combined are requested
-    if(plot.time) {
+    if(plot.time && plot.seasons) {
         
         if(plot.seasons && n.seasons >= 12) {
             n.seasons.adj <- 11
@@ -505,7 +541,8 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
             }
         }
         
-        par(mfrow = c(nRows, nCols))
+        ##reset graphics parameters and save in object
+        oldpar <- par(mfrow = c(nRows, nCols))
     }
 
         
@@ -558,7 +595,7 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
 
 
     ##quantiles for entire data
-    time.table.full <- quantile(uncensoredData.full)
+    time.table.full <- quantile(uncensoredData.full, na.rm = TRUE)
 
     ##store data for each season
 
@@ -608,12 +645,14 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
         ncensored <- nsites - sum(uncensoredIndex)
 
         ##summarize times per season
-        time.quantiles <- quantile(uncensoredData)
+        time.quantiles <- quantile(uncensoredData, na.rm = TRUE)
         time.table.seasons[[i]] <- time.quantiles
         censored.seasons[i] <- ncensored
 
     }
         
+    ##check if any seasons were not sampled
+    y.seasonsNA <- sapply(yMat.seasons, FUN = function(i) all(is.na(i)))
 
     if(plot.seasons) {
 
@@ -632,7 +671,9 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
             
             
             ##create histogram
-            hist(uncensoredData, xlim = c(0, uniqueDist.seasons[[i]]),
+            ##check for missing season
+            if(y.seasonsNA[i]) {next} #skip to next season if current season not sampled
+            hist(uncensoredData.seasons[[i]], xlim = c(0, uniqueDist.seasons[[i]]),
                  xlab = "Time to detection (min.)",
                  main = main.title,
                  cex.axis = cex.axis, cex.lab = cex.lab, cex.main = cex.main)
@@ -727,35 +768,64 @@ detTime.unmarkedFitOccuTTD <- function(object, plot.time = TRUE, plot.seasons =
             some1 <- out.seasons[[j-1]]$some
             none2 <- out.seasons[[j]]$none
             some2 <- out.seasons[[j]]$some
-            ##colonizations
-            out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
-            ##extinctions
-            out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
-            ##no change
-            out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
-            ##sites both sampled in t and t-1
-            year1 <- c(none1, some1)
-            year2 <- c(none2, some2)
-            out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+
+            ##add check for seasons without sampling or previous season without sampling
+            if(y.seasonsNA[j] || y.seasonsNA[j-1]) {
+                if(y.seasonsNA[j]) {
+                    out.freqs[j, 2:6] <- NA
+                }
+                if(y.seasonsNA[j-1]) {
+                    out.freqs[j, 3:6] <- NA
+                }
+            } else {
+
+                ##colonizations
+                out.freqs[j, 3] <- sum(duplicated(c(some2, none1)))
+                ##extinctions
+                out.freqs[j, 4] <- sum(duplicated(c(some1, none2)))
+                ##no change
+                out.freqs[j, 5] <- sum(duplicated(c(some1, some2))) + sum(duplicated(c(none1, none2)))
+                ##sites both sampled in t and t-1
+                year1 <- c(none1, some1)
+                year2 <- c(none2, some2)
+                out.freqs[j, 6] <- sum(duplicated(c(year1, year2)))
+            }
         }
-        
+                
         ##create a matrix with proportion of sites with colonizations
         ##and extinctions based on raw data
         out.props <- matrix(NA, nrow = nrow(out.freqs), ncol = 4)
         colnames(out.props) <- c("naive.occ", "naive.colonization", "naive.extinction", "naive.static")
         rownames(out.props) <- rownames(out.freqs)
-        out.props[, 1] <- out.freqs[, 2]/out.freqs[, 1]
-        out.props[, 2] <- out.freqs[, 3]/out.freqs[, 6]
-        out.props[, 3] <- out.freqs[, 4]/out.freqs[, 6]
-        out.props[, 4] <- out.freqs[, 5]/out.freqs[, 6]
+
+        for(k in 1:n.seasons) {
+            ##proportion of sites with detections
+            out.props[k, 1] <- out.freqs[k, 2]/out.freqs[k, 1]
+            ##add check for seasons without sampling
+            if(y.seasonsNA[k]) {
+                out.props[k, 2:4] <- NA
+            } else {
+                ##proportion colonized
+                out.props[k, 2] <- out.freqs[k, 3]/out.freqs[k, 6]
+                ##proportion extinct
+                out.props[k, 3] <- out.freqs[k, 4]/out.freqs[k, 6]
+                ##proportion static
+                out.props[k, 4] <- out.freqs[k, 5]/out.freqs[k, 6]
+            }
+        }
+    }
+
+    ##reset to original values
+    if(any(plot.time || plot.seasons)) {
+        on.exit(par(oldpar))
     }
 
-    
     out.det <- list("time.table.full" = time.table.full,
                     "time.table.seasons" = time.table.seasons,
                     "out.freqs" = out.freqs, "out.props" = out.props,
                     "n.seasons" = n.seasons,
-                    "n.visits.season" = n.visits.season)
+                    "n.visits.season" = n.visits.season,
+                    "missing.seasons" = y.seasonsNA)
     class(out.det) <- "detTime"
     return(out.det)
 }
@@ -784,17 +854,32 @@ print.detTime <- function(x, digits = 2, ...) {
     colnames(time.mat) <- names(x$time.table.full)
     rownames(time.mat) <- "Time"
     print(round(time.mat, digits = digits))
-    
+
+    ##if some seasons have not been sampled
+    if(any(x$missing.seasons)) {
+        if(sum(x$missing.seasons) == 1) {
+            cat("\nNote: season", which(x$missing.seasons), "was not sampled\n")
+        } else {
+            cat("\nNote: seasons",
+                paste(which(x$missing.seasons), sep = ", "),
+                "were not sampled\n")
+        }
+    }            
     cat("\nSeason-specific time to detection: \n")
     cat("\n")
     for(i in 1:x$n.seasons) {
-      cat("Season", i, "\n")
-      temp.tab <- x$time.table.seasons[[i]]
-      out.mat <- matrix(temp.tab, nrow = 1)
-      colnames(out.mat) <- names(temp.tab)
-      rownames(out.mat) <- "Time"
-      print(round(out.mat, digits = digits))
-      cat("--------\n\n")
+        if(!x$missing.seasons[i]) {
+            cat("Season", i, "\n")
+        } else {
+            cat("Season", i, "(no sites sampled)", "\n")
+        }
+        
+        temp.tab <- x$time.table.seasons[[i]]
+        out.mat <- matrix(temp.tab, nrow = 1)
+        colnames(out.mat) <- names(temp.tab)
+        rownames(out.mat) <- "Time"
+        print(round(out.mat, digits = digits))
+        cat("--------\n\n")
     }
     
     cat("Frequencies of sites with detections, extinctions, and colonizations:\n")
